@@ -20,10 +20,8 @@
 
 #include <KUniqueApplication>
 #include <KShortcut>
-#include <KUrl>
 #include <klocale.h>
 
-class KCmdLineArgs;
 class KeysManager;
 class KGpgExternalActions;
 class QString;
